<?php

namespace Litepie\Company\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Company\Interfaces\CompanyRepositoryInterface;

class CompanyPublicController extends BaseController
{
    // use CompanyWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Company\Interfaces\CompanyRepositoryInterface $company
     *
     * @return type
     */
    public function __construct(CompanyRepositoryInterface $company)
    {
        $this->repository = $company;
        parent::__construct();
    }

    /**
     * Show company's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $companies = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$company::$company.names'))
            ->view('$company::public.company.index')
            ->data(compact('$companies'))
            ->output();
    }

    /**
     * Show company's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $companies = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$company::$company.names'))
            ->view('$company::public.company.index')
            ->data(compact('$companies'))
            ->output();
    }

    /**
     * Show company.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $company = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$company->name . trans('$company::$company.name'))
            ->view('$company::public.company.show')
            ->data(compact('$company'))
            ->output();
    }

}
